import { app } from "../App";
import { API, EquipForgingBench, PetEquip } from "../consts/API";
import { GUI } from "../ui/UIConfig";
import BaseData from "./BaseData";
import PlayerPetData from "./PlayerPetData";

export enum PetEquipDataEnum{
    //更新锻造数据
    UPDATE_FORGING_INFO = "PetEquipDataEnum_UPDATE_FORGING_INFO",
    //更新装备
    UPDATE_EQUIP = "PetEquipDataEnum_UPDATE_EQUIP"
}

//宠物装备数据类
export default class PetEquipData extends BaseData{

    //装备
    equips:PetEquip[];
    //锻造台
    info:EquipForgingBench;

    //锻造台是否有宠物
    get isForgingBenchPet(){
        return !!PlayerPetData.getIns().petIdQueryPetInfo(this.info.forgingPetId);
    }

    async onInit() {
        this.equips = await API.PetEquipAll();
        this.info = await API.PetEquipForgingInfo();
    }

    //更新锻造数据
    onUpdateInfo(info:EquipForgingBench){
        this.info = info;
        app.event.emit(PetEquipDataEnum.UPDATE_FORGING_INFO);
    }

    //锻造
    async forging(){
        return this.addEquip(await API.PetEquipForging());
    }

    //添加装备
    addEquip(equip:PetEquip):PetEquip{
        if(!equip) return null;
        console.log("添加装备",equip)
        if(this.equips.filter(item => item.equipId == equip.equipId).length) return null;
        this.equips.push(equip);
        return equip;
    }

    //设置锻造宠
    async setForgingPetId(petId:number){
        this.onUpdateInfo(await API.PetEquipForgingPetId(petId));
    }

    //穿戴指定装备
    async wear(equip:PetEquip){
        if(this.equips.indexOf(equip) < 0) {
            app.layer.Open(GUI.Tips,{text:"装备不存在"});
            return;
        }
        let info = await API.PetEquipWear(this.info.forgingPetId,equip.equipId);
        if(info){
            //脱下之前的装备
            this.equips.forEach(item => {
                if(info.equipPetId == item.equipPetId && item.equipPosition == info.equipPosition){
                    item.equipPetId = 0;
                }
            })
            Object.assign(equip,info);
            app.event.emit(PetEquipDataEnum.UPDATE_EQUIP);
        }
    }

    //获取指定宠物指定位置的装备
    getPetEquip(position:number,petId:number = this.info.forgingPetId){
        if(!petId) return null;
        return this.equips.filter(equip => (equip.equipPetId == petId && equip.equipPosition == position))[0];
    }


}